(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     58388,       1374]
NotebookOptionsPosition[     30809,        798]
NotebookOutlinePosition[     55679,       1294]
CellTagsIndexPosition[     55636,       1291]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["SRG and NCSM", "Title",
 CellChangeTimes->{{3.515241323603434*^9, 3.515241345381414*^9}}],

Cell["\<\
SRG evolution in three-nucleon space
NCSM solution for the triton \
\>", "Subtitle",
 CellChangeTimes->{{3.515241349865473*^9, 3.5152414124715652`*^9}, {
  3.645433095378317*^9, 3.645433097796411*^9}}],

Cell[CellGroupData[{

Cell["Initialization", "Section",
 CellChangeTimes->{{3.5152989666610193`*^9, 3.51529896921885*^9}}],

Cell["\<\
Here are some constants that will be needed later-on as well as some optional \
settings for the graphics output. Please evaluate these cells when you start \
working with this notebook.\
\>", "Item",
 CellChangeTimes->{{3.515300112086081*^9, 3.5153001724754868`*^9}, {
  3.515308974485653*^9, 3.515308981633462*^9}, {3.6454331058515997`*^9, 
  3.645433107865551*^9}}],

Cell["\<\
hbarc = 197.327053;                    (* [MeV fm] *)
MN0 = (938.27231 + 939.56563)/2;       (* average nucleon mass [MeV] *)
MN  = MN0/hbarc^2 ;     \t\t\t   (* average nucleon mass in units [1/(MeV \
fm^2)] *)\
\>", "Input",
 CellChangeTimes->{{3.444448011601282*^9, 3.444448013848761*^9}, {
  3.5152442119971457`*^9, 3.515244288070447*^9}, {3.51529193401068*^9, 
  3.5152919369055233`*^9}, {3.515300053196741*^9, 3.515300101604507*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"ArrayPlot", ",", " ", 
    RowBox[{"ColorFunction", "\[Rule]", "\"\<SunsetColors\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"DensityPlot", ",", " ", 
    RowBox[{"ColorFunction", "\[Rule]", "\"\<SunsetColors\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"ListDensityPlot", ",", " ", 
    RowBox[{"ColorFunction", "\[Rule]", "\"\<SunsetColors\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"ListLinePlot", ",", " ", 
    RowBox[{"PlotMarkers", "\[Rule]", "Automatic"}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"Axes", "\[Rule]", "False"}], ",", " ", 
    RowBox[{"AspectRatio", "\[Rule]", "0.8"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.515290480026371*^9, 3.515290500351708*^9}, {
  3.515299534606942*^9, 3.5152995581868963`*^9}, {3.515299888932732*^9, 
  3.515299893000996*^9}, {3.515300654892482*^9, 3.515300670120162*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Initial Hamiltonian", "Section",
 CellChangeTimes->{{3.515257884379283*^9, 3.515257889372558*^9}, {
  3.515290674410906*^9, 3.515290674826132*^9}}],

Cell[TextData[{
 "In this project we solve the quantum many-body problem for the ground state \
of the triton (",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[InvisiblePrefixScriptBase]", "3"], "H"}], 
   TraditionalForm]]],
 ") using an SRG-transformed chiral Hamiltonian in the No-Core Shell Model."
}], "Item",
 CellChangeTimes->{{3.51528972467844*^9, 3.515289828702935*^9}, {
  3.5153031505250463`*^9, 3.515303209732542*^9}, {3.6454333260278177`*^9, 
  3.645433328749219*^9}}],

Cell["\<\
In a first step, we prepare the initial Hamiltonian, which is given in a \
matrix represenation using a three-body Jacobi-coordinate harmonic-oscillator \
basis. Those matrix elements are provided via external data files. \
\>", "Item",
 CellChangeTimes->{{3.515289833681922*^9, 3.515289953428165*^9}, {
  3.645888740486977*^9, 3.645888740574836*^9}}],

Cell["\<\
The initial Hamiltonian is composed of the kinetic energy T and the \
interaction V, which in our case is the most recent chiral two- plus \
three-nucleon interaction used also in the lecture on ab initio methods. \
\>", "Item",
 CellChangeTimes->{{3.5152579011614723`*^9, 3.51525793870011*^9}, {
  3.51528998202815*^9, 3.515290058120118*^9}}],

Cell["\<\
In order to allow for numerical calculations, these two operators have to be \
represented in a suitable basis, i.e., the matrix elements of the operators \
for all combinations of two basis states are used as input. The basis of \
choice for the present application in the three-nucleon system is a \
antisymmetrized three-body Jacobi-coordinate harmonic oscillator basis. This \
basis never appears explicitly in this notebook (because it's quite \
complicated), but it was used to compute the matrix elements which are \
provided in the data files.  \
\>", "Item",
 CellChangeTimes->{{3.515290071600205*^9, 3.515290272464521*^9}, {
  3.515303266606062*^9, 3.515303298930769*^9}}],

Cell["\<\
First we have to set the working directory to the place, where you have put \
the matrix element files. You might have to change the following statement \
accordingly.\
\>", "Item",
 CellChangeTimes->{{3.515290274249484*^9, 3.515290323571677*^9}, 
   3.515290386491825*^9, {3.515303331151115*^9, 3.515303332615052*^9}, 
   3.6458887307155533`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", "\"\<~/Desktop/\>\"", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.5152414309623117`*^9, 3.51524145395592*^9}, 
   3.5152415227025337`*^9, 3.645433506648342*^9}],

Cell["\<\
The following commands read in the kinetic energy and the interaction matrix \
elements from the two files and store them in two matrix-type variables TMat \
and VMat, respectively.  \
\>", "Item",
 CellChangeTimes->{{3.51525810193097*^9, 3.515258134813878*^9}, {
   3.515290338330676*^9, 3.5152903829486*^9}, 3.515303372938512*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"TMat", " ", "=", " ", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<kinetic_EMax20_hw20.dat\>\"", ",", " ", "\"\<Table\>\""}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VMat", " ", "=", " ", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<chi2b3b_EMax20_hw20.dat\>\"", ",", " ", "\"\<Table\>\""}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.515241457693*^9, 3.515241537589781*^9}}],

Cell["\<\
First we visualize these matrices. We use the ArrayPlot[] command to plot the \
abolute values of the kinetic energy (TMat) and the potential matrix elements \
(VMat), respectively. What do you observe?\
\>", "Item",
 CellChangeTimes->{{3.515290433045863*^9, 3.5152904723841877`*^9}, {
  3.5152905318522043`*^9, 3.51529062167216*^9}, {3.515303393576223*^9, 
  3.51530350905182*^9}}],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{
   RowBox[{"Abs", "[", "TMat", "]"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "3"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5152416366386747`*^9, 3.515241697121607*^9}, {
  3.515241766260994*^9, 3.5152417899086647`*^9}, {3.515258074918631*^9, 
  3.515258075132804*^9}, {3.515290489158332*^9, 3.515290518383992*^9}}],

Cell[BoxData[
 RowBox[{"ArrayPlot", "[", 
  RowBox[{
   RowBox[{"Abs", "[", "VMat", "]"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "3"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5152416366386747`*^9, 3.515241697121607*^9}, {
   3.515241766260994*^9, 3.5152417899086647`*^9}, {3.515258074918631*^9, 
   3.515258075132804*^9}, 3.515290489158332*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["SRG Evolution", "Section",
 CellChangeTimes->{{3.515258007950039*^9, 3.515258010745205*^9}, 
   3.515290681523039*^9}],

Cell[CellGroupData[{

Cell["Formalism and Algorithm", "Subsection",
 CellChangeTimes->{{3.515291758230986*^9, 3.515291764754567*^9}}],

Cell["\<\
Now we implement the SRG-evolution of the Hamiltonian using the kinetic \
energy and potential matrix elements from above.  \
\>", "Item",
 CellChangeTimes->{{3.515290705186389*^9, 3.5152907775259037`*^9}, 
   3.515303524850595*^9}],

Cell["\<\
We start from the evolution equation for the operators with a flow parameter \
a and expand the commutators\
\>", "Item",
 CellChangeTimes->{{3.5152907866872*^9, 3.515290795510211*^9}, {
  3.515290930806711*^9, 3.515290988838176*^9}, {3.515291124484702*^9, 
  3.515291137771965*^9}, {3.515303762873646*^9, 3.515303783543899*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["d", "da"], 
   RowBox[{"H", "[", "a", "]"}]}], " ", "=", " ", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"=", 
    RowBox[{
     SuperscriptBox["MN", "2"], " ", "[", 
     RowBox[{
      RowBox[{"[", 
       RowBox[{"T", ",", 
        RowBox[{"H", "[", "a", "]"}]}], "]"}], ",", " ", 
      RowBox[{"H", "[", "a", "]"}]}], "]"}]}], "=", " ", 
   RowBox[{
    SuperscriptBox["MN", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"T", " ", 
       RowBox[{"H", "[", "a", "]"}], " ", 
       RowBox[{"H", "[", "a", "]"}]}], " ", "-", " ", 
      RowBox[{"2", " ", 
       RowBox[{"H", "[", "a", "]"}], " ", "T", " ", 
       RowBox[{"H", "[", "a", "]"}]}], " ", "+", " ", 
      RowBox[{
       RowBox[{"H", "[", "a", "]"}], " ", 
       RowBox[{"H", "[", "a", "]"}], " ", "T"}]}], ")"}]}]}]}]], "Equation",
 CellChangeTimes->{
  3.515290798495768*^9, {3.515290843063352*^9, 3.515290920748766*^9}, {
   3.5152910632376337`*^9, 3.5152911167103777`*^9}, {3.515291251174217*^9, 
   3.5152912782133503`*^9}, {3.5152918965193567`*^9, 3.515291898302302*^9}}],

Cell["\<\
By using the Jacobi HO basis representation this translates into a matrix \
evolution equation\
\>", "Item",
 CellChangeTimes->{{3.5152911423687*^9, 3.515291173967288*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["d", "da"], 
   RowBox[{"HMat", "[", "a", "]"}]}], " ", "=", " ", "\[IndentingNewLine]", 
  RowBox[{"=", 
   RowBox[{
    SuperscriptBox["MN", "2"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TMat", ".", 
       RowBox[{"HMat", "[", "a", "]"}], ".", 
       RowBox[{"HMat", "[", "a", "]"}]}], " ", "-", " ", 
      RowBox[{"2", " ", 
       RowBox[{
        RowBox[{"HMat", "[", "a", "]"}], ".", "TMat", ".", 
        RowBox[{"HMat", "[", "a", "]"}]}]}], " ", "+", " ", 
      RowBox[{
       RowBox[{"HMat", "[", "a", "]"}], ".", 
       RowBox[{"HMat", "[", "a", "]"}], ".", "TMat"}]}], 
     ")"}]}]}]}]], "Equation",
 CellChangeTimes->{
  3.515290798495768*^9, {3.515290843063352*^9, 3.515290920748766*^9}, {
   3.5152910632376337`*^9, 3.5152911167103777`*^9}, {3.5152911907863894`*^9, 
   3.515291244667391*^9}, 3.515291282613371*^9, {3.515291884063099*^9, 
   3.515291892526083*^9}}],

Cell["\<\
We can solve this matrix evolution equation using the simplest possible \
algorithm for treating ordinary differential equations numerically, the \
so-called Euler algorithm. It is derived by simply replacing the drivative on \
the left-hand-side by a finite difference approximation for a small step aDel\
\
\>", "Item",
 CellChangeTimes->{{3.515291308018732*^9, 3.515291457039742*^9}, {
  3.515303575309176*^9, 3.5153035814923077`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["d", "da"], 
  RowBox[{
   RowBox[{"HMat", "[", "a", "]"}], " ", "\[LongRightArrow]", "  ", 
   FractionBox["1", "aDel"]}], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"HMat", "[", 
     RowBox[{"a", "+", "aDel"}], "]"}], " ", "-", " ", 
    RowBox[{"HMat", "[", "a", "]"}]}], ")"}]}]], "Equation",
 CellChangeTimes->{{3.515291493512306*^9, 3.515291521373364*^9}, 
   3.515307117457649*^9}],

Cell["\<\
After some simple algebra we obtain the following explicit equation, which \
gives the matrix HMat for flow parameter a+aDel based on the matrixes TMat \
and HMat at flow parameter a, i.e., it brings us one step further in the flow \
parameter a. \
\>", "Item",
 CellChangeTimes->{{3.515291539440487*^9, 3.51529154051618*^9}, {
  3.515291577228812*^9, 3.515291577731328*^9}, {3.5152916170017548`*^9, 
  3.5152917172839937`*^9}, {3.5153037014958344`*^9, 3.515303719855541*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"HMat", "[", 
   RowBox[{"a", " ", "+", " ", "aDel"}], "]"}], " ", "=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{"=", 
   RowBox[{
    RowBox[{"HMat", "[", "a", "]"}], " ", "+", " ", 
    RowBox[{"aDel", " ", 
     SuperscriptBox["MN", "2"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"TMat", ".", 
        RowBox[{"HMat", "[", "a", "]"}], ".", 
        RowBox[{"HMat", "[", "a", "]"}]}], " ", "-", " ", 
       RowBox[{"2", " ", 
        RowBox[{
         RowBox[{"HMat", "[", "a", "]"}], ".", "TMat", ".", 
         RowBox[{"HMat", "[", "a", "]"}]}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{"HMat", "[", "a", "]"}], ".", 
        RowBox[{"HMat", "[", "a", "]"}], ".", "TMat"}]}], 
      ")"}]}]}]}]}]], "Equation",
 CellChangeTimes->{
  3.515290798495768*^9, {3.515290843063352*^9, 3.515290920748766*^9}, {
   3.5152910632376337`*^9, 3.5152911167103777`*^9}, {3.5152911907863894`*^9, 
   3.515291244667391*^9}, 3.515291282613371*^9, {3.515291588676566*^9, 
   3.515291610051304*^9}, {3.515291905806964*^9, 3.515291910438715*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Implementation", "Subsection",
 CellChangeTimes->{{3.515291738568768*^9, 3.5152917496097927`*^9}}],

Cell["\<\
We implement the Euler-type evolution directly. We set a small step size aDel \
and prepare the initial Hamiltonian matrix, given by the sum of the kinetic \
energy matrix and the interaction matrix.\
\>", "Item",
 CellChangeTimes->{{3.515291776801811*^9, 3.515291856492342*^9}, {
  3.51529204296596*^9, 3.51529205075663*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a", " ", "=", " ", "0.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"aDel", " ", "=", " ", "0.0001"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"HMat", " ", "=", " ", 
   RowBox[{"TMat", " ", "+", " ", "VMat"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.515243652400633*^9, 3.515243676573627*^9}, 
   3.515258005528977*^9, {3.515291865629594*^9, 3.5152918663903027`*^9}, {
   3.5152922853238983`*^9, 3.515292288961193*^9}, {3.515293244776339*^9, 
   3.5152932450168533`*^9}}],

Cell["\<\
For storing the SRG-evolved interaction matrix elements, we use a set of \
variables VMatSRG[a], where a is the numerical value of the flow-parameter\
\>", "Item",
 CellChangeTimes->{{3.51529765108854*^9, 3.5152976587708187`*^9}, {
  3.515297791707727*^9, 3.515297850330145*^9}, {3.515303814620173*^9, 
  3.515303827347044*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "VMatSRG", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"VMatSRG", "[", "0.0", "]"}], " ", "=", " ", "VMat"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.515293358044388*^9, 3.5152933699202967`*^9}, {
  3.515297629284136*^9, 3.5152976400512114`*^9}}],

Cell["\<\
We evaluate a single step of the Euler algorithm according to the above \
equiation (4). Since the step size aDel has to be very small in order to make \
the algorithm work, we have to do many steps to evolve the matrices to \
sizable flow-parameters a. Therefore, we always do 500 evolution steps in a \
row using a simple Do-loop. The evaluation of this little program takes some \
time...\
\>", "Item",
 CellChangeTimes->{{3.515258420513083*^9, 3.515258495034589*^9}, {
  3.515291983415262*^9, 3.515292215164777*^9}, {3.51529232063083*^9, 
  3.515292337845689*^9}, {3.515293253920045*^9, 3.5152932593497047`*^9}, {
  3.5153038803761463`*^9, 3.515303881702373*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Do", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"HMatDel", " ", "=", " ", 
       RowBox[{"aDel", " ", 
        RowBox[{"MN", "^", "2"}], " ", 
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{"TMat", ".", "HMat", ".", "HMat"}], " ", "-", " ", 
          RowBox[{"2", " ", 
           RowBox[{"HMat", ".", "TMat", ".", "HMat"}]}], " ", "+", " ", 
          RowBox[{"HMat", ".", "HMat", ".", "TMat"}]}], " ", ")"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"HMat", " ", "=", " ", 
       RowBox[{"HMat", " ", "+", " ", "HMatDel"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"a", " ", "=", " ", 
       RowBox[{"a", "+", "aDel"}]}], ";"}], "\[IndentingNewLine]", ",", 
     RowBox[{"{", "500", "}"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", " ", "=", " ", 
   RowBox[{"Round", "[", 
    RowBox[{"a", ",", "0.00001"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"VMatSRG", "[", "a", "]"}], " ", "=", " ", 
    RowBox[{"HMat", "-", "TMat"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Evolution up to a=\>\"", "<>", 
    RowBox[{"ToString", "[", "a", "]"}], "<>", "\"\< completed.\>\""}], "]"}],
   ";"}]}], "Input",
 CellChangeTimes->{{3.515243614883772*^9, 3.515243640578217*^9}, 
   3.515243681793483*^9, {3.5152442971375237`*^9, 3.515244330561859*^9}, {
   3.51524437914135*^9, 3.515244405460823*^9}, 3.515244439304*^9, {
   3.515291948780408*^9, 3.515291971162917*^9}, {3.515292301290205*^9, 
   3.515292306097947*^9}, {3.515293249417152*^9, 3.515293312826756*^9}, {
   3.515293651408268*^9, 3.5152936581831627`*^9}, {3.5152982688816843`*^9, 
   3.515298279808611*^9}}],

Cell["\<\
Note that this code just continues the evolution from the latest values of \
the variables HMat and a. Thus, if you evaluate the cell a second or third \
time, you will continue the evolution to larger a. The intermediate results \
for the evolved interaction matrix elements are stored in the variables \
VMatSRG[0.05], VMatSRG[0.1],... Make sure that you evaluate the above cell at \
least twice!\
\>", "Item",
 CellChangeTimes->{{3.51529380202337*^9, 3.515293930991371*^9}, {
  3.515297573819682*^9, 3.5152976214107037`*^9}, {3.5152985011221247`*^9, 
  3.5152985138022957`*^9}}],

Cell["\<\
We can create plots of the initial interaction matrix elements and the \
evolved ones for direct comparison. What do you observe?\
\>", "Item",
 CellChangeTimes->{{3.515297877231317*^9, 3.515297934486864*^9}}],

Cell[BoxData[{
 RowBox[{"ArrayPlot", "[", " ", 
  RowBox[{
   RowBox[{"Abs", "[", 
    RowBox[{"VMatSRG", "[", "0.0", "]"}], "]"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "3"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"ArrayPlot", "[", " ", 
  RowBox[{
   RowBox[{"Abs", "[", 
    RowBox[{"VMatSRG", "[", "0.05", "]"}], "]"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "3"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"ArrayPlot", "[", " ", 
  RowBox[{
   RowBox[{"Abs", "[", 
    RowBox[{"VMatSRG", "[", "0.1", "]"}], "]"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "3"}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5152436952300043`*^9, 3.515243728309512*^9}, 
   3.515244632074003*^9, {3.5152580620361958`*^9, 3.515258062267926*^9}, 
   3.5152923479110947`*^9, {3.5152934910067997`*^9, 3.515293522467621*^9}, {
   3.5152937797543697`*^9, 3.5152937856482973`*^9}, {3.515297940202238*^9, 
   3.5152979453365726`*^9}, {3.515298408552985*^9, 3.5152984109351797`*^9}, {
   3.515298488388762*^9, 3.515298494460821*^9}, {3.515298529315578*^9, 
   3.515298532033619*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["No-Core Shell Model", "Section",
 CellChangeTimes->{{3.515258610597291*^9, 3.515258611855206*^9}, {
  3.5153001853730183`*^9, 3.515300190648841*^9}}],

Cell["\<\
Finally, we can solve the exact Schr\[ODoubleDot]dinger equation for the \
triton via a matrix eigenvalue problem, which corresponds to a full-fledged \
No-Core Shell Model calculation.\
\>", "Item",
 CellChangeTimes->{{3.515297973163558*^9, 3.515298062378296*^9}, {
  3.515304429493759*^9, 3.515304437964479*^9}, {3.645835696331317*^9, 
  3.645835707906747*^9}}],

Cell[CellGroupData[{

Cell["Implementation", "Subsection",
 CellChangeTimes->{{3.645433266509923*^9, 3.645433272688533*^9}}],

Cell["\<\
In Mathematica this is essentially a one-line program once we have the \
Hamiltonian matrix elements available. We use the command Eigenvalues[] to \
abtain the 5 eigenvalues of lowest magnitude and select the smallest one from \
these, since we are only interested in the ground state. \
\>", "Item",
 CellChangeTimes->{{3.51529806602794*^9, 3.515298195229495*^9}}],

Cell["For the initial Hamiltonian we get", "Item",
 CellChangeTimes->{{3.5152983535522757`*^9, 3.515298369678898*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"HMat", " ", "=", " ", 
   RowBox[{"TMat", " ", "+", " ", 
    RowBox[{"VMatSRG", "[", "0.0", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Min", "[", 
  RowBox[{"Eigenvalues", "[", 
   RowBox[{"HMat", ",", " ", 
    RowBox[{"-", "5"}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5152415646019297`*^9, 3.515241613487144*^9}, {
   3.515298201670476*^9, 3.5152982244464006`*^9}, 3.515298440712447*^9}],

Cell["For the SRG-evolved Hamiltonian we get for a=0.05", "Item",
 CellChangeTimes->{{3.5152983535522757`*^9, 3.515298369678898*^9}, {
  3.515298468043757*^9, 3.515298477466776*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"HMat", " ", "=", " ", 
   RowBox[{"TMat", " ", "+", " ", 
    RowBox[{"VMatSRG", "[", "0.05", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Min", "[", 
  RowBox[{"Eigenvalues", "[", 
   RowBox[{"HMat", ",", " ", 
    RowBox[{"-", "5"}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5152415646019297`*^9, 3.515241613487144*^9}, {
   3.515298201670476*^9, 3.5152982244464006`*^9}, 3.515298384872614*^9, 
   3.51529844579025*^9}],

Cell["For the SRG-evolved Hamiltonian we get for a=0.1", "Item",
 CellChangeTimes->{{3.5152983535522757`*^9, 3.515298369678898*^9}, {
  3.515298468043757*^9, 3.515298477466776*^9}, {3.5152986120560427`*^9, 
  3.515298614237767*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"HMat", " ", "=", " ", 
   RowBox[{"TMat", " ", "+", " ", 
    RowBox[{"VMatSRG", "[", "0.1", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Min", "[", 
  RowBox[{"Eigenvalues", "[", 
   RowBox[{"HMat", ",", " ", 
    RowBox[{"-", "5"}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5152415646019297`*^9, 3.515241613487144*^9}, {
   3.515298201670476*^9, 3.5152982244464006`*^9}, 3.515298384872614*^9, 
   3.51529844579025*^9, {3.515298624704328*^9, 3.515298624999797*^9}}],

Cell["\<\
The eigenvalues we obtain are almost the same for all three Hamiltonians, \
which is due to the unitarity of the transformation. Do you have any idea why \
they are not exactly the same?\
\>", "Item",
 CellChangeTimes->{{3.515298456017119*^9, 3.515298461493107*^9}, {
  3.515298559424149*^9, 3.5152985860647984`*^9}, {3.5152986822126703`*^9, 
  3.515298740688027*^9}, {3.515304104113143*^9, 3.515304124636859*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Convergence", "Subsection",
 CellChangeTimes->{{3.5152986385650663`*^9, 3.5152986413980722`*^9}}],

Cell[TextData[{
 "We can also look at the convergence behavior of the different Hamiltonians. \
In order to do so, we extract from the full Hamiltonian matrix a sequence of \
submatrices that correspond to the different ",
 Cell[BoxData[
  FormBox["NMax", TraditionalForm]]],
 "-truncated model spaces for NMax=2,...,20. For this we need the sizes of \
the submatrices corresponding to the different NMax-truncated spaces, which \
are given in the following cell:"
}], "Item",
 CellChangeTimes->{{3.515298758820129*^9, 3.515298922424849*^9}, {
  3.515299597477363*^9, 3.515299646007142*^9}, {3.515304145066992*^9, 
  3.515304155097934*^9}, {3.515304260526232*^9, 3.515304260910448*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NMaxList", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "4", ",", "6", ",", "8", ",", "10", ",", "12", ",", "14", ",", 
     "16", ",", "18", ",", "20"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DimList", " ", "=", 
   RowBox[{"{", 
    RowBox[{
    "5", ",", "15", ",", "34", ",", "64", ",", "108", ",", "169", ",", "249", 
     ",", "351", ",", "478", ",", "632"}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.515299089685158*^9, 3.515299129399845*^9}, {
  3.515299326986052*^9, 3.5152993287678137`*^9}, {3.515299396832621*^9, 
  3.5152994052467813`*^9}}],

Cell["\<\
Now we can extract a sequence of submatrices and solve the eigenvalue problem \
for each of them. This gives us the ground-state energies for the triton for \
a sequence of NMax values, which are returned by the following cell as a list \
with entries {NMax, EE0}. We start with the initial Hamiltonian:\
\>", "Item",
 CellChangeTimes->{{3.515299654929203*^9, 3.515299755742922*^9}, {
  3.51530426664624*^9, 3.515304302275489*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EEList", "[", "0.0", "]"}], " ", "=", " ", 
  RowBox[{"Table", "[", " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"HMat", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{
        RowBox[{"TMat", " ", "+", " ", 
         RowBox[{"VMatSRG", "[", "0.0", "]"}]}], ",", " ", 
        RowBox[{"DimList", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
        RowBox[{"DimList", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"EE0", " ", "=", "  ", 
      RowBox[{"Min", "[", 
       RowBox[{"Eigenvalues", "[", 
        RowBox[{"HMat", ",", 
         RowBox[{"-", "5"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"NMaxList", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", " ", "EE0"}], "}"}]}], ",", " ", 
    
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "NMaxList", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.515299135110697*^9, 3.5152992384527473`*^9}, 
   3.515299302607692*^9, {3.515299366310644*^9, 3.515299437690628*^9}}],

Cell["And now we do the same for the SRG-evolved Hamiltonians", "Item",
 CellChangeTimes->{{3.5152997589417458`*^9, 3.515299786156283*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EEList", "[", "0.05", "]"}], " ", "=", " ", 
  RowBox[{"Table", "[", " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"HMat", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{
        RowBox[{"TMat", " ", "+", " ", 
         RowBox[{"VMatSRG", "[", "0.05", "]"}]}], ",", " ", 
        RowBox[{"DimList", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
        RowBox[{"DimList", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"EE0", " ", "=", "  ", 
      RowBox[{"Min", "[", 
       RowBox[{"Eigenvalues", "[", 
        RowBox[{"HMat", ",", 
         RowBox[{"-", "5"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"NMaxList", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", " ", "EE0"}], "}"}]}], ",", " ", 
    
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "NMaxList", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.515299135110697*^9, 3.5152992384527473`*^9}, 
   3.515299302607692*^9, {3.515299366310644*^9, 3.5152994514176207`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EEList", "[", "0.1", "]"}], " ", "=", " ", 
  RowBox[{"Table", "[", " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"HMat", " ", "=", " ", 
      RowBox[{"Take", "[", 
       RowBox[{
        RowBox[{"TMat", " ", "+", " ", 
         RowBox[{"VMatSRG", "[", "0.1", "]"}]}], ",", " ", 
        RowBox[{"DimList", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
        RowBox[{"DimList", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"EE0", " ", "=", "  ", 
      RowBox[{"Min", "[", 
       RowBox[{"Eigenvalues", "[", 
        RowBox[{"HMat", ",", 
         RowBox[{"-", "5"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"NMaxList", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", " ", "EE0"}], "}"}]}], ",", " ", 
    
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "NMaxList", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.515299135110697*^9, 3.5152992384527473`*^9}, 
   3.515299302607692*^9, {3.515299366310644*^9, 3.515299469988451*^9}}],

Cell["\<\
We can visualize the results in a combined convergence plot for the three \
Hamiltonians, showing the ground-state energies as function of NMax. This is \
the type of plot that was shown in the lecture as well. What do you observe?\
\>", "Item",
 CellChangeTimes->{{3.51529978992201*^9, 3.515299862842795*^9}, {
  3.515304323238854*^9, 3.5153043304548693`*^9}}],

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"EEList", "[", "0.0", "]"}], ",", 
    RowBox[{"EEList", "[", "0.05", "]"}], ",", 
    RowBox[{"EEList", "[", "0.1", "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.515299473301049*^9, 3.515299513344323*^9}, 
   3.515299567529647*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Further Studies", "Section",
 CellChangeTimes->{{3.515299923690662*^9, 3.5152999590387707`*^9}}],

Cell["\<\
You can play with the above components and study, e.g., what happens for \
larger flow parameters or what changes if you reverse the direction of the \
flow. \
\>", "Item",
 CellChangeTimes->{{3.51529996558914*^9, 3.515300032892764*^9}, {
   3.515304346957369*^9, 3.5153043716991253`*^9}, 3.515307313377927*^9, {
   3.645433781610835*^9, 3.645433832414946*^9}, {3.645433958541074*^9, 
   3.645433961341776*^9}, 3.645434021259368*^9}],

Cell["\<\
You can also implement better solvers for the SRG part or try the Mathematica \
NDSolve[] command instead of the simplistic Euler algorithm. \
\>", "Item",
 CellChangeTimes->{{3.645433963863277*^9, 3.645433972844253*^9}, {
  3.6454340245436*^9, 3.6454340278738117`*^9}}],

Cell["\<\
You can also invent and test new generators for the SRG evolution.\
\>", "Item",
 CellChangeTimes->{{3.645433963863277*^9, 3.645433972844253*^9}, {
  3.6454340245436*^9, 3.6454340278738117`*^9}, {3.64543406443712*^9, 
  3.6454340952390337`*^9}}],

Cell["\<\
If you are interested in algorithms, you could also try to implement a simple \
Lanczos algorithm for solving the eigenvalue problem for the Hamilton matrix \
for the lowest eigenstates. It\[CloseCurlyQuote]s just a few lines of code ;-)\
\>", "Item",
 CellChangeTimes->{{3.645433963863277*^9, 3.645433972844253*^9}, {
  3.6454340245436*^9, 3.6454340278738117`*^9}, {3.64543406443712*^9, 
  3.6454341866008663`*^9}}]
}, Closed]]
},
WindowToolbars->{},
WindowSize->{809, 939},
WindowMargins->{{287, Automatic}, {Automatic, 16}},
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell["Style Definitions", "Subtitle"], 
      Cell[
      "Modify the definitions below to change the default appearance of all \
cells in a given style.  Make modifications to any definition using commands \
in the Format menu.", "Text"], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Names", "Section"], 
         Cell[
          StyleData[All, "Working"], PageWidth -> WindowWidth, ScriptMinSize -> 
          9], 
         Cell[
          StyleData[All, "Printout"], PageWidth -> PaperWidth, ScriptMinSize -> 
          7, FontSize -> 10, 
          PrivateFontOptions -> {"FontType" -> "Outline"}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Notebook Options", "Section"], 
         Cell[
         "The options defined for the style below will be used at the \
Notebook level.", "Text"], 
         Cell[
          StyleData["Notebook"], PageHeaders -> {{
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"], None, 
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"]}, {
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"], None, 
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"]}}, PageFooters -> {{
             Cell[
              TextData[{
                ValueBox["Date"]}], "Footer"], None, None}, {None, None, 
             Cell[
              TextData[{
                ValueBox["Date"]}], "Footer"]}}, 
          CellBracketOptions -> {"Color" -> RGBColor[0, 0, 0.466667]}, 
          StyleMenuListing -> None]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Header Graphic (to be pasted in)", "Section"], 
         Cell[
          StyleData["HeaderCell"], ShowCellBracket -> False, 
          CellMargins -> {{0, 0}, {0, 0}}, Evaluatable -> False, 
          PageBreakBelow -> False, ImageSize -> {1, 1}, 
          ImageMargins -> {{0, 0}, {0, 0}}, ImageRegion -> {{0, 1}, {0, 1}}, 
          StyleMenuListing -> None]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headings", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {0, 0}}, PageBreakBelow -> False, 
             LineSpacing -> {1, 0}, 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}}, FontFamily -> "Palatino", FontSize -> 36, 
             FontWeight -> "Plain", FontSlant -> "Italic", 
             FontVariations -> {
              "Outline" -> False, "Shadow" -> False, "StrikeThrough" -> False,
                "Underline" -> False}, FontColor -> GrayLevel[1], Background -> 
             RGBColor[0.299992, 0.299992, 0.699992]], 
            Cell[
             StyleData["Title", "Printout"], CellMargins -> {{0, 0}, {0, 0}}, 
             CellFrameMargins -> {{5, 0}, {5, 5}}, FontSize -> 24]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {0, 0}}, PageBreakBelow -> False, 
             LineSpacing -> {1.1, 0}, 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}}, FontFamily -> "Palatino", FontSize -> 24, 
             FontWeight -> "Plain", FontSlant -> "Italic", 
             FontVariations -> {
              "StrikeThrough" -> False, "Underline" -> False}, FontColor -> 
             GrayLevel[1], Background -> 
             RGBColor[0.450004, 0.450004, 0.900008]], 
            Cell[
             StyleData["Subtitle", "Printout"], 
             CellMargins -> {{0, 0}, {0, 0}}, 
             CellFrameMargins -> {{5, 0}, {5, 5}}, FontSize -> 18]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {0, 0}}, PageBreakBelow -> False, 
             LineSpacing -> {1.1, 0}, 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}}, FontFamily -> "Palatino", FontSize -> 18, 
             FontWeight -> "Plain", FontSlant -> "Italic", 
             FontVariations -> {
              "StrikeThrough" -> False, "Underline" -> False}, FontColor -> 
             GrayLevel[1], Background -> RGBColor[0.549996, 0.549996, 1]], 
            Cell[
             StyleData["Subsubtitle", "Printout"], 
             CellMargins -> {{0, 0}, {0, 0}}, 
             CellFrameMargins -> {{5, 0}, {5, 5}}, FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> {{0, 0}, {0, 2}}, CellDingbat -> 
             None, CellMargins -> {{10, 0}, {10, 35}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> 
             False, CellFrameMargins -> {{5, 0}, {6, 4}}, CellFrameColor -> 
             RGBColor[0.299992, 0.299992, 0.699992], LineSpacing -> {0, 22}, 
             CounterIncrements -> "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
               "Exercise", 0}}, FontFamily -> "Arial", FontSize -> 22, 
             FontWeight -> "Plain", FontSlant -> "Plain", FontTracking -> 
             "Plain", 
             FontVariations -> {
              "CompatibilityType" -> 0, "Masked" -> False, "Outline" -> False,
                "RotationAngle" -> 0, "Shadow" -> False, "StrikeThrough" -> 
               False, "Underline" -> False}, FontColor -> GrayLevel[0], 
             Background -> RGBColor[0.970779, 0.898436, 0.686671]], 
            Cell[
             StyleData["Section", "Printout"], CellFrame -> {{0, 0}, {0, 1}}, 
             CellMargins -> {{0, 0}, {8, 20}}, 
             CellFrameMargins -> {{5, 0}, {3, 3}}, FontSize -> 16]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellFrame -> False, CellDingbat -> 
             "\[FilledSmallSquare]", CellMargins -> {{30, 0}, {4, 20}}, 
             CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
             False, CellFrameMargins -> {{0, 0}, {0, 2}}, CellFrameColor -> 
             RGBColor[0.2, 0.700008, 0.700008], CounterIncrements -> 
             "Subsection", CounterAssignments -> {{"Subsubsection", 0}}, 
             FontFamily -> "Arial", FontSize -> 18, FontWeight -> "Bold", 
             FontSlant -> "Plain", FontTracking -> "Plain", 
             FontVariations -> {
              "Outline" -> False, "Shadow" -> False, "Underline" -> False}, 
             FontColor -> RGBColor[0.299992, 0.299992, 0.699992]], 
            Cell[
             StyleData["Subsection", "Printout"], 
             CellMargins -> {{20, 0}, {5, 10}}, FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellFrame -> False, CellDingbat -> 
             "\[FilledSmallSquare]", 
             CellMargins -> {{43, Inherited}, {4, 10}}, Evaluatable -> False, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, CellFrameMargins -> {{0, 0}, {0, 2}}, CounterIncrements -> 
             "Subsubsection", FontFamily -> "Arial", FontSize -> 16, 
             FontWeight -> "Bold", FontSlant -> "Plain", FontTracking -> 
             "Plain", 
             FontVariations -> {
              "CompatibilityType" -> 0, "Masked" -> False, "Outline" -> False,
                "RotationAngle" -> 0, "Shadow" -> False, "StrikeThrough" -> 
               False, "Underline" -> False}, FontColor -> 
             RGBColor[0.299992, 0.299992, 0.699992]], 
            Cell[
             StyleData["Subsubsection", "Printout"], 
             CellMargins -> {{30, Inherited}, {5, 5}}, FontSize -> 12]}, 
           Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Body Text", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], CellMargins -> {{60, 20}, {4, 6}}, 
             LineSpacing -> {1.1, 0}, ParagraphSpacing -> {0, 0}, FontFamily -> 
             "Arial", FontSize -> 13, FontWeight -> "Plain", FontSlant -> 
             "Plain", FontTracking -> "Plain", 
             FontVariations -> {
              "CompatibilityType" -> 0, "Masked" -> False, "Outline" -> False,
                "RotationAngle" -> 0, "Shadow" -> False, "StrikeThrough" -> 
               False, "Underline" -> False}, FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["Text", "Printout"], PageWidth -> PaperWidth, 
             CellMargins -> {{36, 0}, {4, 6}}, LineSpacing -> {1.1, 0}, 
             FontSize -> 12, FontWeight -> "Plain"]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Item"], CellDingbat -> "\[FilledSmallCircle] ", 
             CellMargins -> {{60, 20}, {4, 6}}, LineSpacing -> {1.1, 0}, 
             ParagraphSpacing -> {0, 0}, FontFamily -> "Arial", FontSize -> 
             13, FontWeight -> "Bold", FontSlant -> "Plain", FontTracking -> 
             "Plain", 
             FontVariations -> {
              "CompatibilityType" -> 0, "Masked" -> False, "Outline" -> False,
                "RotationAngle" -> 0, "Shadow" -> False, "StrikeThrough" -> 
               False, "Underline" -> False}, FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["Item", "Printout"], PageWidth -> PaperWidth, 
             CellMargins -> {{36, 0}, {4, 6}}, LineSpacing -> {1.1, 0}, 
             FontSize -> 12, FontWeight -> "Plain"]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subitem"], CellDingbat -> "\[EmptySmallSquare]", 
             CellMargins -> {{75, 20}, {4, 6}}, LineSpacing -> {1.1, 0}, 
             ParagraphSpacing -> {0, 0}, FontFamily -> "Arial", FontSize -> 
             13, FontWeight -> "Plain", FontSlant -> "Plain", FontTracking -> 
             "Plain", 
             FontVariations -> {
              "CompatibilityType" -> 0, "Masked" -> False, "Outline" -> False,
                "RotationAngle" -> 0, "Shadow" -> False, "StrikeThrough" -> 
               False, "Underline" -> False}, FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["Subitem", "Printout"], PageWidth -> PaperWidth, 
             CellMargins -> {{48, 0}, {4, 6}}, LineSpacing -> {1.1, 0}, 
             FontSize -> 12, FontWeight -> "Plain"]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Remark"], CellDingbat -> "\[FilledSmallCircle] ", 
             CellMargins -> {{60, 20}, {4, 6}}, Evaluatable -> False, 
             TextJustification -> 0, LineSpacing -> {1.1, 0}, FontFamily -> 
             "Arial", FontSize -> 13, FontWeight -> "Bold", FontSlant -> 
             "Plain", FontTracking -> "Plain", 
             FontVariations -> {
              "CompatibilityType" -> 0, "Masked" -> False, "Outline" -> False,
                "RotationAngle" -> 0, "Shadow" -> False, "StrikeThrough" -> 
               False, "Underline" -> False}, FontColor -> 
             RGBColor[0.8, 0, 0]], 
            Cell[
             StyleData["Remark", "Printout"], PageWidth -> PaperWidth, 
             CellMargins -> {{36, 0}, {4, 6}}, LineSpacing -> {1.1, 0}, 
             FontSize -> 12, FontWeight -> "Bold", FontSlant -> "Italic"]}, 
           Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Comment"], CellDingbat -> None, 
             CellMargins -> {{60, 20}, {4, 6}}, Evaluatable -> False, 
             TextJustification -> 0, LineSpacing -> {1.1, 0}, FontFamily -> 
             "Arial", FontSize -> 13, FontWeight -> "Plain", FontSlant -> 
             "Plain", FontTracking -> "Plain", 
             FontVariations -> {
              "Outline" -> False, "Shadow" -> False, "Underline" -> False}, 
             FontColor -> GrayLevel[0.6]], 
            Cell[
             StyleData["Comment", "Printout"], PageWidth -> PaperWidth, 
             CellMargins -> {{36, 0}, {4, 6}}, LineSpacing -> {1.1, 0}, 
             FontSize -> 12, FontWeight -> "Plain", FontSlant -> "Plain"]}, 
           Open]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input/Output", "Section"], 
         Cell[
         "The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], PageWidth -> Infinity, 
             CellMargins -> {{60, 20}, {5, 5}}, Evaluatable -> True, 
             CellGroupingRules -> "InputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, 
             LineSpacing -> {1, 3}, AutoItalicWords -> {}, FormatType -> 
             InputForm, ShowStringCharacters -> True, NumberMarks -> True, 
             CounterIncrements -> "Input", FontFamily -> "Courier", FontSize -> 
             12, FontWeight -> "Plain", FontSlant -> "Plain", 
             FontVariations -> {
              "StrikeThrough" -> False, "Underline" -> False}], 
            Cell[
             StyleData["Input", "Printout"], PageWidth -> Infinity, 
             CellMargins -> {{36, 20}, {2, 2}}, FontSize -> 11]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DeactivatedInput"], PageWidth -> Infinity, 
             CellMargins -> {{60, 20}, {5, 5}}, Evaluatable -> False, 
             CellGroupingRules -> "InputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, 
             LineSpacing -> {1, 3}, AutoItalicWords -> {}, FormatType -> 
             InputForm, ShowStringCharacters -> True, FontFamily -> "Courier",
              FontSize -> 12, FontWeight -> "Plain", FontSlant -> "Plain", 
             FontVariations -> {
              "StrikeThrough" -> False, "Underline" -> False}, FontColor -> 
             GrayLevel[0.6]], 
            Cell[
             StyleData["DeactivatedInput", "Printout"], PageWidth -> Infinity,
              CellMargins -> {{36, 20}, {2, 2}}, FontSize -> 10]}, Open]], 
         Cell[
          StyleData["InlineInput"], Evaluatable -> True, CellGroupingRules -> 
          "InputGrouping", CellHorizontalScrolling -> True, PageBreakWithin -> 
          False, GroupPageBreakWithin -> False, DefaultFormatType -> 
          DefaultInputFormatType, "TwoByteSyntaxCharacterAutoReplacement" -> 
          True, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, FormatType -> InputForm, 
          ShowStringCharacters -> True, NumberMarks -> True, 
          CounterIncrements -> "Input", FontFamily -> "Courier", FontSize -> 
          12, FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], PageWidth -> WindowWidth, 
             CellMargins -> {{60, 20}, {10, 5}}, CellEditDuplicate -> True, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, 
             LineSpacing -> {1, 3}, AutoItalicWords -> {}, FormatType -> 
             InputForm, CounterIncrements -> "Output", FontFamily -> 
             "Courier", FontSize -> 12, FontWeight -> "Bold", FontSlant -> 
             "Plain", 
             FontVariations -> {
              "StrikeThrough" -> False, "Underline" -> False}], 
            Cell[
             StyleData["Output", "Printout"], PageWidth -> PaperWidth, 
             CellMargins -> {{36, 20}, {15, 5}}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Graphics"], CellMargins -> {{60, 20}, {10, 10}}, 
             CellGroupingRules -> "GraphicsGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, 
             CellChangeTimes -> {3.443687373468232*^9}, FormatType -> 
             InputForm, CounterIncrements -> "Graphics", 
             ImageSize -> {250, 250}, FontFamily -> "Arial", FontSize -> 11, 
             FontWeight -> "Plain", FontSlant -> "Plain", 
             FontVariations -> {
              "StrikeThrough" -> False, "Underline" -> False}], 
            Cell[
             StyleData["Graphics", "Printout"], CellFrame -> False, 
             CellMargins -> {{36, 20}, {10, 10}}, ImageSize -> {150, 150}, 
             FontFamily -> "Arial", FontSize -> 11, FontWeight -> "Bold"]}, 
           Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Message"], CellMargins -> {{60, 20}, {1, 1}}, 
             CellGroupingRules -> "OutputGrouping", PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, StyleMenuListing -> None, FontFamily -> "Courier", 
             FontSize -> 10, FontWeight -> "Plain", FontSlant -> "Plain", 
             FontVariations -> {
              "StrikeThrough" -> False, "Underline" -> False}, FontColor -> 
             RGBColor[1, 0, 0]], 
            Cell[
             StyleData["Message", "Printout"], 
             CellMargins -> {{36, 20}, {1, 1}}, 
             CellLabelMargins -> {{23, Inherited}, {1, 1}}, FontSize -> 6]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], 
             CellMargins -> {{60, 20}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, ShowCellLabel -> 
             False, CellLabelMargins -> {{23, Inherited}, {
               Inherited, Inherited}}, DefaultFormatType -> 
             DefaultOutputFormatType, FormatType -> InputForm, 
             StyleMenuListing -> None, FontFamily -> "Courier", FontSize -> 
             12, FontWeight -> "Plain", FontSlant -> "Plain", 
             FontVariations -> {
              "StrikeThrough" -> False, "Underline" -> False}], 
            Cell[
             StyleData["Print", "Printout"], 
             CellMargins -> {{36, 20}, {Inherited, Inherited}}, FontSize -> 
             10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Info"], 
             CellMargins -> {{60, 20}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, ShowCellLabel -> 
             False, CellLabelMargins -> {{23, Inherited}, {
               Inherited, Inherited}}, DefaultFormatType -> 
             DefaultOutputFormatType, FormatType -> InputForm, 
             StyleMenuListing -> None, FontFamily -> "Courier", FontSize -> 
             12, FontWeight -> "Plain", FontSlant -> "Plain", 
             FontVariations -> {
              "StrikeThrough" -> False, "Underline" -> False}], 
            Cell[
             StyleData["Info", "Printout"], 
             CellMargins -> {{36, 20}, {Inherited, Inherited}}, FontSize -> 
             10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], StyleMenuListing -> None, FontFamily -> 
             "Arial", FontSize -> 9, FontTracking -> "Extended", FontColor -> 
             GrayLevel[0.500008]], 
            Cell[
             StyleData["CellLabel", "Printout"], FontSize -> 6, FontSlant -> 
             "Italic", FontColor -> GrayLevel[0]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Equations and Specials", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Equation"], CellMargins -> {{75, Inherited}, {4, 6}}, 
             CellHorizontalScrolling -> True, CellFrameLabels -> {{None, 
                Cell[
                 TextData[{"(", 
                   CounterBox["Equation"], ")"}]]}, {None, None}}, 
             DefaultFormatType -> StandardForm, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 0, SingleLetterItalics -> False, 
             SpanMaxSize -> Infinity, CounterIncrements -> "Equation", 
             FontFamily -> "Courier", FontSize -> 12, FontWeight -> "Bold", 
             FontSlant -> "Plain", 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}, 
             GridBoxOptions -> {
              GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1.}}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["Equation", "Printout"], 
             CellMargins -> {{58, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["EquationNoNumber"], 
             CellMargins -> {{75, Inherited}, {4, 6}}, 
             CellHorizontalScrolling -> True, DefaultFormatType -> 
             StandardForm, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 0, SingleLetterItalics -> False, 
             SpanMaxSize -> Infinity, FontFamily -> "Courier", FontSize -> 12,
              FontWeight -> "Bold", FontSlant -> "Plain", 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}, 
             GridBoxOptions -> {
              GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1.}}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["EquationNoNumber", "Printout"], 
             CellMargins -> {{58, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 10]}, Closed]]}, Closed]], 
      Cell["Unique Styles", "Section"], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headers and Footers", "Section"], 
         Cell[
          StyleData["Header"], CellMargins -> {{0, 0}, {1, 1}}, 
          StyleMenuListing -> None, FontFamily -> "Arial", FontSize -> 8, 
          FontWeight -> "Plain", FontSlant -> "Plain", FontTracking -> 
          "Plain", 
          FontVariations -> {
           "CompatibilityType" -> 0, "Masked" -> False, "Outline" -> False, 
            "RotationAngle" -> 0, "Shadow" -> False, "StrikeThrough" -> False,
             "Underline" -> False}], 
         Cell[
          StyleData["Footer"], CellMargins -> {{0, 0}, {0, 1}}, 
          StyleMenuListing -> None, FontFamily -> "Arial", FontSize -> 8, 
          FontSlant -> "Plain"], 
         Cell[
          StyleData["PageNumber"], CellMargins -> {{0, 0}, {1, 1}}, 
          StyleMenuListing -> None, FontFamily -> "Arial", FontSize -> 10, 
          FontSlant -> "Plain"]}, Closed]]}, Open]]}, Visible -> False, 
  FrontEndVersion -> 
  "9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, 2013)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 95, 1, 56, "Title"],
Cell[643, 23, 211, 5, 73, "Subtitle"],
Cell[CellGroupData[{
Cell[879, 32, 100, 1, 82, "Section"],
Cell[982, 35, 378, 7, 42, "Item"],
Cell[1363, 44, 449, 8, 55, "Input"],
Cell[1815, 54, 1103, 25, 72, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[2955, 84, 153, 2, 51, "Section"],
Cell[3111, 88, 495, 12, 44, "Item"],
Cell[3609, 102, 361, 6, 42, "Item"],
Cell[3973, 110, 353, 6, 42, "Item"],
Cell[4329, 118, 692, 11, 91, "Item"],
Cell[5024, 131, 357, 7, 42, "Item"],
Cell[5384, 140, 217, 4, 24, "Input"],
Cell[5604, 146, 342, 6, 42, "Item"],
Cell[5949, 154, 448, 11, 40, "Input"],
Cell[6400, 167, 392, 7, 42, "Item"],
Cell[6795, 176, 427, 9, 24, "Input"],
Cell[7225, 187, 405, 9, 24, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[7667, 201, 124, 2, 51, "Section"],
Cell[CellGroupData[{
Cell[7816, 207, 111, 1, 45, "Subsection"],
Cell[7930, 210, 242, 5, 42, "Item"],
Cell[8175, 217, 339, 6, 25, "Item"],
Cell[8517, 225, 1113, 30, 61, "Equation"],
Cell[9633, 257, 182, 4, 25, "Item"],
Cell[9818, 263, 944, 25, 61, "Equation"],
Cell[10765, 290, 448, 8, 58, "Item"],
Cell[11216, 300, 425, 12, 41, "Equation"],
Cell[11644, 314, 486, 8, 58, "Item"],
Cell[12133, 324, 1083, 27, 42, "Equation"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13253, 356, 104, 1, 45, "Subsection"],
Cell[13360, 359, 336, 6, 42, "Item"],
Cell[13699, 367, 532, 11, 54, "Input"],
Cell[14234, 380, 338, 6, 42, "Item"],
Cell[14575, 388, 324, 8, 39, "Input"],
Cell[14902, 398, 677, 11, 75, "Item"],
Cell[15582, 411, 1846, 44, 160, "Input"],
Cell[17431, 457, 591, 10, 75, "Item"],
Cell[18025, 469, 219, 4, 42, "Item"],
Cell[18247, 475, 1236, 28, 56, "Input"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[19532, 509, 155, 2, 51, "Section"],
Cell[19690, 513, 373, 7, 42, "Item"],
Cell[CellGroupData[{
Cell[20088, 524, 102, 1, 45, "Subsection"],
Cell[20193, 527, 376, 6, 58, "Item"],
Cell[20572, 535, 118, 1, 25, "Item"],
Cell[20693, 538, 446, 10, 40, "Input"],
Cell[21142, 550, 182, 2, 25, "Item"],
Cell[21327, 554, 472, 11, 40, "Input"],
Cell[21802, 567, 232, 3, 25, "Item"],
Cell[22037, 572, 517, 11, 40, "Input"],
Cell[22557, 585, 424, 7, 42, "Item"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23018, 597, 103, 1, 45, "Subsection"],
Cell[23124, 600, 686, 12, 75, "Item"],
Cell[23813, 614, 634, 15, 39, "Input"],
Cell[24450, 631, 441, 7, 58, "Item"],
Cell[24894, 640, 1159, 30, 71, "Input"],
Cell[26056, 672, 139, 1, 25, "Item"],
Cell[26198, 675, 1163, 30, 71, "Input"],
Cell[27364, 707, 1159, 30, 71, "Input"],
Cell[28526, 739, 371, 6, 58, "Item"],
Cell[28900, 747, 326, 8, 23, "Input"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[29275, 761, 102, 1, 51, "Section"],
Cell[29380, 764, 443, 8, 42, "Item"],
Cell[29826, 774, 280, 5, 42, "Item"],
Cell[30109, 781, 255, 5, 25, "Item"],
Cell[30367, 788, 426, 7, 42, "Item"]
}, Closed]]
}
]
*)

(* End of internal cache information *)
